@@ -3,13 +3,14 @@
 #' Calculation of historical decomposition for an identified SVAR object 'svars' derived by function id.st( ), id.cvm( ),id.cv( ),id.dc( ) or id.ngml( ).
 #'
 #' @param x SVAR object of class "svars"
-#' @param series Integer indicating the series that should be decomposed.
+#' @param series Integer. indicating the series that should be decomposed.
+#' @param transition Numeric. Value from [0, 1] indicating how many initial values should be discarded, i.e., 0.1 means that the first 10 per cent observations of the sample are considered as transient.
 #'
 #' @return A list with class attribute "hd" holding the historical decomposition as data frame.
 #'
 #' @references Kilian, L., Luetkepohl, H., 2017. Structural Vector Autoregressive Analysis, Cambridge University Press.
 #'
-#' @seealso \code{\link{id.cvm}}, \code{\link{id.dc}}, \code{\link{id.ngml}}, \code{\link{id.cv}} or \code{\link{id.st}}
+#' @seealso \code{\link{id.cvm}}, \code{\link{id.dc}}, \code{\link{id.ngml}}, \code{\link{id.cv}}, \code{\link{id.garch}} or \code{\link{id.st}}
 #'
 #' @examples
 #' \donttest{
@@ -21,7 +22,7 @@
 #'
 #' @export
 
-hd <- function(x, series = 1){
+hd <- function(x, series = 1, transition = 0){
 
   # Function to calculate matrix potence
   "%^%" <- function(A, n){
@@ -91,8 +92,14 @@ hd <- function(x, series = 1){
 
   # Step 2: Calculate structural errors
 
-  # gathering informations from vars object
+  # gathering informations from 'svars' object
+
+  # in case original data came in different format than matrix or ts
+  if(!inherits(x$y, c("matrix", "ts"))){
+    y = as.matrix(x$y)
+  }else{
   y <- x$y
+  }
   p <- x$p
   obs <- x$n
   k <- x$K
@@ -100,7 +107,7 @@ hd <- function(x, series = 1){
 
   # calculating covariance from actual VAR
   A <- x$A_hat
-  Z <- t(YLagCr(y, p))
+  Z <- t(YLagCr(as.matrix(y), p))
 
   if(x$type == "const"){
     Z <- rbind(rep(1, ncol(Z)), Z)
@@ -119,25 +126,39 @@ hd <- function(x, series = 1){
   # Step 3: Match up structural shocks with appropriate impuslse response
   impulse <- impulse[,-1]
   y_hat <- matrix(NA, nrow = obs, ncol = k)
-  for(i in 1:obs){
-    for(j in 1:k){
-      y_hat[i,j] <- impulse[1:i, j+series-1] %*% t(s.errors)[i:1,j]
+
+  if (transition == 0) {
+    for (i in 1:obs) {
+      for (j in 1:k) {
+        y_hat[i, j] <- impulse[1:i, j + series * k - k] %*% t(s.errors)[i:1, j]
+      }
+    }
+  } else {
+    for (i in (obs - floor(obs * (1 - transition))):obs) {
+      for (j in 1:k) {
+        y_hat[i, j] <- impulse[(obs - floor(obs * (1 - transition))):i, j + series * k - k] %*% t(s.errors)[i:(obs - floor(obs * (1 - transition))), j]
+      }
     }
   }
 
+
+
   y_hat_a <- rowSums(y_hat)
 
-  yhat <- as.data.frame(cbind(seq(1, length(y_hat_a)), y_hat_a, y_hat))
+  yhat <- as.data.frame(cbind(seq(1, length(y_hat_a)), (y[-c(1:p), series] - mean(y[-c(1:p), series])), y_hat_a, y_hat))
 
-  colnames(yhat)[2] <- colnames(y)[series]
+  colnames(yhat)[3] <- paste("Constructed series ", colnames(y)[series])
+  colnames(yhat)[2] <- paste("Demeaned series ", colnames(y)[series])
 
-  for(i in 3:ncol(yhat)){
-    colnames(yhat)[i] <- paste("Cumulative effect of flow ", colnames(y)[i-2], "shock on ", colnames(y)[series])
+  for(i in 4:ncol(yhat)){
+    colnames(yhat)[i] <- paste("Cumulative effect of flow ", colnames(y)[i-3], "shock on ", colnames(y)[series])
   }
+
   if(inherits(x$y, "ts")){
-  histdecomp <- list(hidec = ts(yhat[, -grep("V1", colnames(yhat))], start = start(lag(x$y, k = -x$p)), end = end(x$y), frequency = frequency(x$y)))
+    hidec <- ts(yhat[, -grep("V1", colnames(yhat))], start = start(lag(x$y, k = -x$p)), end = end(x$y), frequency = frequency(x$y))
+    histdecomp <- list(hidec = na.omit(hidec))
 }else{
-  histdecomp <- list(hidec = as.data.frame(yhat))
+   histdecomp <- list(hidec = as.data.frame(na.omit(yhat)))
 }
   class(histdecomp) <- "hd"
   return(histdecomp)
