@@ -4,39 +4,13 @@ identifyNGML <- function(x, coef_x, Sigma_hat, u, k, p, Tob, yOut, type, y,
   B_l <- t(chol(Sigma_hat))
   # standardized choleski decomp
   B_l_st <- B_l%*%solve(diag(diag(B_l)))
-
-  # starting values
-  if(!is.null(restriction_matrix)){
-    naElements <- is.na(restriction_matrix)
-    beta0 <- B_l_st[row(B_l)!=col(B_l)]
-    beta0 <- beta0[-(which(!is.na(restriction_matrix))-floor(which(!is.na(restriction_matrix))/k))]
-    restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
-    diag(naElements) <- FALSE
-  }else{
-    beta0 <- B_l_st[row(B_l)!=col(B_l)]
-    restrictions <- 0
-  }
-  sigma0 <- rep(1,k)
-  lambda0 <- rep(5,k)
-  theta0 <- c(beta0,sigma0,lambda0)
-
-  # Creating selection matrix for likelihood
-  il <- matrix(0, k*k, k*k)
-  rows <- rep(0, k)
-  for(i in 1:k){
-    if(i == 1){
-      il[i,i] <- 1
-      rows[i] <- 1
-    }else{
-      il[(i+(k*(i-1))),(i+(k*(i-1)))] <- 1
-      rows[i] <- i+(k*(i-1))
-    }
-  }
+  restriction_matrix = get_restriction_matrix(restriction_matrix, k)
+  restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
 
   # Creating matrix with off diagonal elemts
   B_hat <- function(beta, k){
     B_hat <- diag(k)
-    if(!is.null(restriction_matrix)){
+    if(restrictions > 0){
       B_hat[naElements] <- beta
     }else{
       B_hat[row(B_hat)!=col(B_hat)] <- beta
@@ -44,10 +18,29 @@ identifyNGML <- function(x, coef_x, Sigma_hat, u, k, p, Tob, yOut, type, y,
     return(B_hat)
   }
 
+  # starting values
+  if(restrictions > 0){
+    naElements <- is.na(restriction_matrix)
+    beta0 <- B_l_st[row(B_l)!=col(B_l)]
+    beta0 <- beta0[-(which(!is.na(restriction_matrix))-floor(which(!is.na(restriction_matrix))/k))]
+    restrictions <- length(restriction_matrix[!is.na(restriction_matrix)])
+    diag(naElements) <- FALSE
+
+    restriction_matrix_optim <- restriction_matrix
+  }else{
+    beta0 <- B_l_st[row(B_l)!=col(B_l)]
+    #restrictions <- 0
+
+    restriction_matrix_optim <- restriction_matrix
+  }
+
+  sigma0 <- rep(1,k)
+  lambda0 <- rep(5,k)
+  theta0 <- c(beta0,sigma0,lambda0)
+
   # optimizing the likelihood function 2. stage
-  maxL <- nlm(p = theta0, f = likelihood_ngml_stage2, u = u, k = k, il = il, rows = rows, restriction_matrix = restriction_matrix,
-              restrictions = restrictions,
-              hessian = TRUE)
+  maxL <- nlm(p = theta0, f = LikelihoodNGMLStage2, u = u, k = k, RestrictionMatrix = restriction_matrix_optim, Tob = Tob,
+              restrictions = restrictions, hessian = TRUE)
   beta_est <- maxL$estimate[1:(k*k-k-restrictions)]
 
   sigma_est <- maxL$estimate[(k*k-k+1-restrictions):(k*k-restrictions)]
@@ -63,7 +56,7 @@ identifyNGML <- function(x, coef_x, Sigma_hat, u, k, p, Tob, yOut, type, y,
       HESS[,i] <- -HESS[,i]
     }
   }
-  if(!is.null(restriction_matrix)){
+  if(restrictions > 0){
     unRestrictions = k*k-k - restrictions
     FishObs <- sqrt(diag(HESS))
     B.SE <- restriction_matrix
@@ -98,7 +91,7 @@ identifyNGML <- function(x, coef_x, Sigma_hat, u, k, p, Tob, yOut, type, y,
   # Estimating VAR parameter 3. stage
   if(stage3 == TRUE){
     #y <- t(x$y)
-    yl <- t(y_lag_cr(t(y), p)$lags)
+    yl <- t(YLagCr(t(y), p))
     y_return <- y
 
     y <- y[,-c(1:p)]
@@ -150,9 +143,9 @@ identifyNGML <- function(x, coef_x, Sigma_hat, u, k, p, Tob, yOut, type, y,
     }
 
     A <- c(A)
-    maxL2 <- nlm(p = A, f = likelihood_ngml_stage3, Z_t = Z_t, y = y, il = il,
-                 B_stand_est = B_stand_est, rows = rows, sigma_est = sigma_est,
-                 d_freedom = d_freedom, Tob = Tob, k=k, hessian = TRUE)
+    maxL2 <- nlm(p = A, f = LikelihoodNGMLStage3, Z_t = Z_t, Y = y,
+                 B_stand_est = B_stand_est, sigma_est = sigma_est,
+                 d_freedom = d_freedom, Tob = Tob, k = k, hessian = TRUE)
 
     A_hat <- matrix(maxL2$estimate, nrow = k)
     y <- y_return
