@@ -1,6 +1,7 @@
 #' @import ggplot2
 #' @importFrom reshape2 melt
-#' @S3method plot svarirf
+#' @method plot svarirf
+#' @export
 
 plot.svarirf <- function(x, base, scales = "free_y", ...){
 
@@ -8,7 +9,7 @@ plot.svarirf <- function(x, base, scales = "free_y", ...){
   impulse <- melt(x$irf, id = 'V1')
   ggplot(impulse, aes_(x = ~V1, y = ~value)) + geom_line() + geom_hline(yintercept = 0, color = 'red') +
     facet_wrap(~variable, scales = scales, labeller = label_parsed) +
-    xlab("Observation Time") + ylab("Response") +
+    xlab("Horizon") + ylab("Response") +
   theme_bw()
 }
 
