@@ -1,4 +1,4 @@
-#' @S3method summary svars
+#' @export
 
 summary.svars <- function(object, ...){
 
@@ -10,9 +10,11 @@ summary.svars <- function(object, ...){
   cat(svarsObject$method)
   cat("\nSample size: ")
   cat(svarsObject$n)
-  if(!svarsObject$method %in% c("Distance covariances", "Cramer-von Mises distance")){
-  cat("\nLikelihood: ")
+  if(!svarsObject$method %in% c("Distance covariances", "Cramer-von Mises distance", "Cholesky")){
+  cat("\nLog-Likelihood: ")
   cat(svarsObject$Lik)
+  cat("\nAIC: ")
+  cat(svarsObject$AIC)
 }
   if(svarsObject$method ==  "Changes in Volatility"){
   cat("\nStructural Break: At Observation Number ")
@@ -111,7 +113,7 @@ summary.svars <- function(object, ...){
      #cat(svarsObject$lRatioTestPValue)
      printCoefmat(svarsObject$lRatioTest, has.Pvalue = T)
    }
- }else if(svarsObject$method == "Distance covariances"){
+ }else if(svarsObject$method == "Distance covariances" | svarsObject$method == "Cholesky"){
    cat("\n")
    cat("\nEstimated B Matrix (unique decomposition of the covariance matrix): \n")
    print(svarsObject$B)
